==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/controllers/vyrobajs.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 11.09.2018
 */

namespace Ron\RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\RonPortal\NeniPravoException;
use Ron\RonPortal\PracovniPomer;
use Ron\RonPortal\Prava;
use Ron\RonPortal\User;
use Ron\StringUtils;


class VyrobaJsController extends JsonController
{
    /** @var Database */
    private $database;

    /**
     * VyrobaJsController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        $this->enableAccessWithoutLogin = true; // pouziva se pro rozdeleni vyroby z prihlasovaciho formulare
    }


    /**
     * Nacte cinnosti, ktere ma zadany pracovni pomer (idpp) v dane dny povolene na zadane zakazce
     * @param JsonOutputObject $output
     */
    function cinnostiZakazky($output)
    {
        require_once 'adsapp/ppomer.php';
        require_once 'vyroba/cinnostdennivyroby.php';

        $pp = PracovniPomer::nactiPP($this->database, $_GET['idpp']);
        $den = DateUtils::urlStringToDate($_GET['den']);
        $denDo = isset($_GET['denDo']) ? DateUtils::urlStringToDate($_GET['denDo']) : $den;

        $cinnosti = CinnostDenniVyroby::nactiPrirazeneCinnosti($this->database, $pp, $den, $denDo, $_GET['zakazka']);

        $data = [];
        foreach ($cinnosti as $cinnost) {
            $data[] = [
                'key' => $cinnost->cinnostVyrobniZakazky,
                'value' => StringUtils::jsonText($cinnost->popis)
            ];
        }

        $output->addData('options', $data);
    }


//    /**
//     * @param JsonOutputObject $output
//     * @throws NeniPravoException
//     * @throws \Exception
//     */
//    function podrobnostiZaznamu($output)
//    {
//        if (!$_GET['serial']) {
//            return;
//        }
//
//        require_once 'vyroba/zaznamvyroby.php';
//        $zaznam = ZaznamVyroby::nactiZaznamVyroby($this ->database, (int)$_GET['serial']);
//
//        if (!Prava::lzeZobrazitPP('editace', $zaznam ->idPP)) {
//            throw new NeniPravoException();
//        }
//
//        $data = [
//            'popis' => StringUtils::jsonText($zaznam ->popis),
//            'rozsirujiciPopis' => StringUtils::jsonText($zaznam ->rozsirujiciPopis)
//        ];
//
//        $output ->addData('data', $data);
//    }


    /**
     * @param JsonOutputObject $output
     */
    function nactiRadkyZObdobi($output)
    {

    }


    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'cinnostizakazky' :
                $this ->cinnostiZakazky($output);
                return;

            case 'doplnitradky' :
                $this ->nactiRadkyZObdobi($output);
                return;

//            case 'podrobnosti' :
//                $this ->podrobnostiZaznamu($output);
//                return;
        }

        if (!User::isAuthenticated()) {
            throw new NeniPravoException();
        }
    }
}

return new VyrobaJsController($this ->database);

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/controllers/vyrobajs.php <==
<?php
/**
 * stanislav.elbl, 11.09.2018
 */

namespace RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\StringUtils;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\User;


class VyrobaJsController extends JsonController
{
    /** @var Database */
    private $database;

    /**
     * VyrobaJsController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        $this->enableAccessWithoutLogin = true; // pouziva se pro rozdeleni vyroby z prihlasovaciho formulare
    }


    /**
     * Nacte cinnosti, ktere ma zadany pracovni pomer (idpp) v dane dny povolene na zadane zakazce
     * @param JsonOutputObject $output
     */
    function cinnostiZakazky($output)
    {
        $pp = PracovniPomer::nactiPP($this->database, $_GET['idpp']);
        $den = DateUtils::urlStringToDate($_GET['den']);
        $denDo = isset($_GET['denDo']) ? DateUtils::urlStringToDate($_GET['denDo']) : $den;

        $cinnosti = CinnostDenniVyroby::nactiPrirazeneCinnosti($this->database, $pp, $den, $denDo, $_GET['zakazka']);

        $data = [];
        foreach ($cinnosti as $cinnost) {
            $data[] = [
                'key' => $cinnost->cinnostVyrobniZakazky,
                'value' => StringUtils::jsonText($cinnost->popis)
            ];
        }

        $output->addData('options', $data);
    }


//    /**
//     * @param JsonOutputObject $output
//     * @throws NeniPravoException
//     * @throws \Exception
//     */
//    function podrobnostiZaznamu($output)
//    {
//        if (!$_GET['serial']) {
//            return;
//        }
//
//        require_once 'vyroba/zaznamvyroby.php';
//        $zaznam = ZaznamVyroby::nactiZaznamVyroby($this ->database, (int)$_GET['serial']);
//
//        if (!Prava::lzeZobrazitPP('editace', $zaznam ->idPP)) {
//            throw new NeniPravoException();
//        }
//
//        $data = [
//            'popis' => StringUtils::jsonText($zaznam ->popis),
//            'rozsirujiciPopis' => StringUtils::jsonText($zaznam ->rozsirujiciPopis)
//        ];
//
//        $output ->addData('data', $data);
//    }


    /**
     * @param JsonOutputObject $output
     */
    function nactiRadkyZObdobi($output)
    {

    }


    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'cinnostizakazky' :
                $this ->cinnostiZakazky($output);
                return;

            case 'doplnitradky' :
                $this ->nactiRadkyZObdobi($output);
                return;

//            case 'podrobnosti' :
//                $this ->podrobnostiZaznamu($output);
//                return;
        }

        if (!User::isAuthenticated()) {
            throw new NeniPravoException();
        }
    }
}

return new VyrobaJsController($this ->database);
